package pipeline

import (
	"context"
	"strings"

	"github.com/pkg/errors"
	"github.com/smartcontractkit/chainlink/core/logger"
	"go.uber.org/multierr"
)

//
// Return types:
//     string
//
type UppercaseTask struct {
	BaseTask `mapstructure:",squash"`
	Input    string `json:"input"`
}

var _ Task = (*UppercaseTask)(nil)

func (t *UppercaseTask) Type() TaskType {
	return TaskTypeUppercase
}

func (t *UppercaseTask) Run(_ context.Context, _ logger.Logger, vars Vars, inputs []Result) (result Result, runInfo RunInfo) {
	_, err := CheckInputs(inputs, 0, 1, 0)
	if err != nil {
		return Result{Error: errors.Wrap(err, "task inputs")}, runInfo
	}

	var input StringParam

	err = multierr.Combine(
		errors.Wrap(ResolveParam(&input, From(VarExpr(t.Input, vars), Input(inputs, 0))), "input"),
	)
	if err != nil {
		return Result{Error: err}, runInfo
	}

	return Result{Value: strings.ToUpper(string(input))}, runInfo
}
